@@ -5,8 +5,8 @@ use Mojo::Asset::File;
 use Mojo::Asset::Memory;
 use Mojo::Content::MultiPart;
 use Mojo::Content::Single;
-use Mojo::File 'path';
-use Mojo::JSON 'encode_json';
+use Mojo::File qw(path);
+use Mojo::JSON qw(encode_json);
 use Mojo::Parameters;
 use Mojo::Transaction::HTTP;
 use Mojo::Transaction::WebSocket;
